@@ -23,3 +23,11 @@ class TestAssembleWORD(TestCase):
         self.assertEqual([
             (0x1000, [0x03, 0x10]),
         ], results)
+
+    def test_words(self):
+        code = ".ORG $1000\n" \
+               ".WORD $ABCD, $EF42"
+        results = self.assembler.assemble(code, add_entry=False)
+        self.assertEqual([
+            (0x1000, [0xCD, 0xAB, 0x42, 0xEF]),
+        ], results)
